summaryrefslogtreecommitdiffstats
path: root/fs/bcachefs/btree_update.h
diff options
context:
space:
mode:
authorKent Overstreet <kent.overstreet@linux.dev>2023-06-27 17:32:38 -0400
committerKent Overstreet <kent.overstreet@linux.dev>2023-10-22 17:10:05 -0400
commitec14fc6010fdcc40e54e289afc657a676ce93e72 (patch)
treee8fba04ba538c638d926763706411559a43016a6 /fs/bcachefs/btree_update.h
parent494036d862dfff1de9782492692da225479b7146 (diff)
downloadlinux-stable-ec14fc6010fdcc40e54e289afc657a676ce93e72.tar.gz
linux-stable-ec14fc6010fdcc40e54e289afc657a676ce93e72.tar.bz2
linux-stable-ec14fc6010fdcc40e54e289afc657a676ce93e72.zip
bcachefs: Kill JOURNAL_WATERMARK
This unifies JOURNAL_WATERMARK with BCH_WATERMARK; we're working towards specifying watermarks once in the transaction commit path. Signed-off-by: Kent Overstreet <kent.overstreet@linux.dev>
Diffstat (limited to 'fs/bcachefs/btree_update.h')
-rw-r--r--fs/bcachefs/btree_update.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/fs/bcachefs/btree_update.h b/fs/bcachefs/btree_update.h
index 8911a7f79f1c..8ecb87533cf3 100644
--- a/fs/bcachefs/btree_update.h
+++ b/fs/bcachefs/btree_update.h
@@ -23,8 +23,8 @@ void bch2_btree_insert_key_leaf(struct btree_trans *, struct btree_path *,
struct bkey_i *, u64);
enum btree_insert_flags {
- /* First two bits for journal watermark: */
- __BTREE_INSERT_NOFAIL = 2,
+ /* First bits for bch_watermark: */
+ __BTREE_INSERT_NOFAIL = BCH_WATERMARK_BITS,
__BTREE_INSERT_NOCHECK_RW,
__BTREE_INSERT_LAZY_RW,
__BTREE_INSERT_USE_RESERVE,